@@ -1,3 +1,5 @@
+from __future__ import absolute_import, print_function, division
+
 import numpy as np
 
 from . import math_util as m
@@ -34,8 +36,8 @@ def resample(array, factor):
 
     nx, ny = np.shape(array)
 
-    nx_new = nx / factor
-    ny_new = ny / factor
+    nx_new = nx // factor
+    ny_new = ny // factor
 
     array2 = np.zeros((nx_new, ny))
     for i in range(nx_new):
@@ -88,3 +90,35 @@ def stretch(array, function, exponent=2, midpoint=None):
         return np.power(array, exponent)
     else:
         raise Exception("Unknown function : " + function)
+
+
+def _matplotlib_pil_bug_present():
+    """
+    Determine whether PIL images should be pre-flipped due to a bug in Matplotlib.
+
+    Prior to Matplotlib 1.2.0, RGB images provided as PIL objects were
+    oriented wrongly. This function tests whether the bug is present.
+    """
+
+    from matplotlib.image import pil_to_array
+
+    try:
+        from PIL import Image
+    except:
+        import Image
+
+    from astropy import log
+
+    array1 = np.array([[1,2],[3,4]], dtype=np.uint8)
+    image = Image.fromarray(array1)
+    array2 = pil_to_array(image)
+
+    if np.all(array1 == array2):
+        log.debug("PIL Image flipping bug not present in Matplotlib")
+        return False
+    elif np.all(array1 == array2[::-1,:]):
+        log.debug("PIL Image flipping bug detected in Matplotlib")
+        return True
+    else:
+        log.warn("Could not properly determine Matplotlib behavior for RGB images - image may be flipped incorrectly")
+        return False
