@@ -1,10 +1,20 @@
+from __future__ import absolute_import, print_function, division
+
 import numpy as np
-import pywcs
-
-from .logger import logger
 
 
-class WCS(pywcs.WCS):
+from astropy import log
+from astropy.wcs import WCS as AstropyWCS
+
+
+def decode_ascii(string):
+    try:
+        return string.decode('ascii')
+    except AttributeError:
+        return string
+
+
+class WCS(AstropyWCS):
 
     def __init__(self, *args, **kwargs):
 
@@ -14,7 +24,7 @@ class WCS(pywcs.WCS):
         if 'dimensions' in kwargs:
             self._dimensions = kwargs.pop('dimensions')
 
-        pywcs.WCS.__init__(self, *args, **kwargs)
+        AstropyWCS.__init__(self, *args, **kwargs)
 
         # Fix common non-standard units
         self.wcs.unitfix()
@@ -40,7 +50,7 @@ class WCS(pywcs.WCS):
                     coords.append(np.repeat(self._slices[s], xpix.shape))
                     s += 1
             coords = np.vstack(coords).transpose()
-            result = pywcs.WCS.wcs_pix2sky(self, coords, 1)
+            result = AstropyWCS.wcs_pix2sky(self, coords, 1)
             self._mean_world = np.mean(result, axis=0)
             # result = result.transpose()
             # result = result.reshape((result.shape[0],) + (self.ny, self.nx))
@@ -92,25 +102,25 @@ class WCS(pywcs.WCS):
             raise AttributeError("Attribute %s does not exist" % attribute)
 
         if attribute[:5] == 'ctype':
-            return self.wcs.ctype[axis]
+            return decode_ascii(self.wcs.ctype[axis])
         elif attribute[:5] == 'cname':
-            return self.wcs.cname[axis]
+            return decode_ascii(self.wcs.cname[axis])
         elif attribute[:5] == 'cunit':
-            return self.wcs.cunit[axis]
+            return str(self.wcs.cunit[axis])
         elif attribute[:5] == 'crval':
-            return self.wcs.crval[axis]
+            return decode_ascii(self.wcs.crval[axis])
         elif attribute[:5] == 'crpix':
-            return self.wcs.crpix[axis]
+            return decode_ascii(self.wcs.crpix[axis])
         else:
             raise AttributeError("Attribute %s does not exist" % attribute)
 
     def wcs_sky2pix(self, x, y, origin):
         if self.naxis == 2:
             if self._dimensions[1] < self._dimensions[0]:
-                xp, yp = pywcs.WCS.wcs_sky2pix(self, y, x, origin)
+                xp, yp = AstropyWCS.wcs_sky2pix(self, y, x, origin)
                 return yp, xp
             else:
-                return pywcs.WCS.wcs_sky2pix(self, x, y, origin)
+                return AstropyWCS.wcs_sky2pix(self, x, y, origin)
         else:
             coords = []
             s = 0
@@ -127,20 +137,20 @@ class WCS(pywcs.WCS):
             coords = np.vstack(coords).transpose()
 
             # Due to a bug in pywcs, we need to loop over each coordinate
-            # result = pywcs.WCS.wcs_sky2pix(self, coords, origin)
+            # result = AstropyWCS.wcs_sky2pix(self, coords, origin)
             result = np.zeros(coords.shape)
             for i in range(result.shape[0]):
-                result[i:i + 1, :] = pywcs.WCS.wcs_sky2pix(self, coords[i:i + 1, :], origin)
+                result[i:i + 1, :] = AstropyWCS.wcs_sky2pix(self, coords[i:i + 1, :], origin)
 
             return result[:, self._dimensions[0]], result[:, self._dimensions[1]]
 
     def wcs_pix2sky(self, x, y, origin):
         if self.naxis == 2:
             if self._dimensions[1] < self._dimensions[0]:
-                xw, yw = pywcs.WCS.wcs_pix2sky(self, y, x, origin)
+                xw, yw = AstropyWCS.wcs_pix2sky(self, y, x, origin)
                 return yw, xw
             else:
-                return pywcs.WCS.wcs_pix2sky(self, x, y, origin)
+                return AstropyWCS.wcs_pix2sky(self, x, y, origin)
         else:
             coords = []
             s = 0
@@ -153,7 +163,7 @@ class WCS(pywcs.WCS):
                     coords.append(np.repeat(self._slices[s] + 0.5, x.shape))
                     s += 1
             coords = np.vstack(coords).transpose()
-            result = pywcs.WCS.wcs_pix2sky(self, coords, origin)
+            result = AstropyWCS.wcs_pix2sky(self, coords, origin)
             return result[:, self._dimensions[0]], result[:, self._dimensions[1]]
 
 
@@ -407,7 +417,7 @@ def system(wcs):
 
     if system['name'] == 'equatorial':
         if equinox == '' or np.isnan(equinox) or equinox == 0.:
-            logger.warning("Cannot determine equinox. Assuming J2000.")
+            log.warning("Cannot determine equinox. Assuming J2000.")
             equinox = 'j2000'
         elif equinox == 1950.:
             equinox = 'b1950'
